@@ -2,23 +2,21 @@
 #'
 #' @description Unbiased estimator for \code{alpha}
 #'
-#' @usage bias.pn(x, model)
+#' @usage pn.bias(x)
 #'
 #'@param x the response vector
-#'@param model a variable returned by \code{\link{pn.mle}}
 #'
 #' @export
 
 
 
-bias.pn <- function(x, model){
-  alpha <- model$alpha
+pn.bias <- function(x){
   dados <- as.matrix(x)
   n <- length(dados)
+  alpha_cor <- -(n-1)/(sum(log(pnorm(x))))
 
 
-
-list(alpha_cor=alpha*(n-1)/n, loglik = .lv_pn(alpha*(n-1)/n,x))
+list(alpha_cor = alpha_cor, loglik = lv_pn(alpha_cor,x))
 }
 
 
